# SMLS
Command Line Interface for the Seamless Cloud

![](https://github.com/seamless-io/seamless-cli/workflows/CI_CD/badge.svg)

Supporting

[![Python 3.6](https://img.shields.io/badge/python-3.6-blue.svg)](https://www.python.org/downloads/release/python-360/)
[![Python 3.7](https://img.shields.io/badge/python-3.7-blue.svg)](https://www.python.org/downloads/release/python-370/)
[![Python 3.8](https://img.shields.io/badge/python-3.8-blue.svg)](https://www.python.org/downloads/release/python-380/)

## Local development
Create virtual environment and run
```pip install -r requirements.txt```

## Install CLI locally
```pip install -e .```

## Run tests locally
```pip install -r test_requirements.txt```

```pytest```
